#!/usr/bin/env python
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Authors:
# - Paul Nilsson, paul.nilsson@cern.ch, 2021-2022

#try:
#    # import dask
#    import dask_kubernetes
#except ModuleNotFoundError:
#    pass

# from pilot.util.container import execute
# from pilot.util.filehandling import establish_logging, write_file

import logging
logger = logging.getLogger(__name__)
